[Jifty-commit] r6633 - in jifty/trunk: lib/Jifty

Jifty commits jifty-commit at lists.jifty.org
Tue Mar 17 14:26:01 EDT 2009


Author: sartak
Date: Tue Mar 17 14:26:01 2009
New Revision: 6633

Modified:
   jifty/trunk/   (props changed)
   jifty/trunk/lib/Jifty/API.pm

Log:
 r81313 at onn:  sartak | 2009-03-17 14:25:56 -0400
 _actions -> all_actions


Modified: jifty/trunk/lib/Jifty/API.pm
==============================================================================
--- jifty/trunk/lib/Jifty/API.pm	(original)
+++ jifty/trunk/lib/Jifty/API.pm	Tue Mar 17 14:26:01 2009
@@ -25,8 +25,11 @@
      Jifty->api->hide(qr/Vote|PurchaseTobacco/);
  }
 
+ # Fetch the class names of all actions
+ my @actions = Jifty->api->all_actions;
+
  # Fetch the class names of all the allowed actions
- my @actions = Jifty->api->actions;
+ my @allowed = Jifty->api->actions;
 
  # Fetch all of the visible actions (some of which may not be allowed)
  my @visible = Jifty->api->visible_actions;
@@ -88,9 +91,9 @@
 }
 
 # Plugin actions under Jifty::Plugin::*::Action are mirrored under
 # AppName::Action by Jifty::ClassLoader; this code makes _actions
 # reflect this mirroring.
-sub _actions {
+sub all_actions {
     my $self = shift;
     unless ( $self->{_actions} ) {
         my @actions = $self->__actions;
@@ -389,7 +392,7 @@
 
 sub actions {
     my $self = shift;
-    return sort grep { not /::SUPER$/ and $self->is_allowed($_) } $self->_actions;
+    return sort grep { not /::SUPER$/ and $self->is_allowed($_) } $self->all_actions;
 }
 
 =head2 visible_actions
@@ -402,7 +405,7 @@
 
 sub visible_actions {
     my $self = shift;
-    return sort grep { not /::SUPER$/ and $self->is_visible($_) } $self->_actions;
+    return sort grep { not /::SUPER$/ and $self->is_visible($_) } $self->all_actions;
 }
 
 =head1 SEE ALSO
@@ -88,9 +91,9 @@
 
 # Plugin actions under Jifty::Plugin::*::Action are mirrored under
-# AppName::Action by Jifty::ClassLoader; this code makes _actions
+# AppName::Action by Jifty::ClassLoader; this code makes all_actions
 # reflect this mirroring.


More information about the Jifty-commit mailing list